@@ -42,9 +42,15 @@ def spider_day(date, question, cookie=None, save_path=None, save_name=None):
 			, 'Cookie': cookie
 		}
 		response = requests.post(url=url, headers=headers, data=params)
-		result = response.json()
-	temp = result['data']['answer'][0]['txt'][0]['content']['components'][0]['data'][
-		'datas']
+		try:
+			result = response.json()
+		except Exception:
+			raise ValueError('cookie无效')
+	if 'result' in dir():
+		temp = result['data']['answer'][0]['txt'][0]['content']['components'][0]['data'][
+			'datas']
+	else:
+		raise ValueError('cookie无效')
 	df_temp = pd.DataFrame(temp)
 	df_temp.dropna(inplace=True)
 	df_temp['date'] = str(date)
